==> MKN_third_codes-0.4.3.1.tar.gz: MKN_third_codes-0.4.3.1/README.md <==
### Здарова! Библиотека немного помогает с тервером по МКН 3

## 📦 Версия: 0.4.3

- Функции buckets_n_balls => задачи про урны
- Функции things_complexity => задачи про путаницу вещей
- Функции geometric_meeting => задачи про встречи
- Функции find_math_prediction => нахождение Математического ожидания
- Функция combinations => число сочетаний

# 🔩 Использование
## 📥 Импортирование
### from MKN_third_codes import solutions
## 🕹 Функции
- 📱 любая функция, решающая задачу имеет суффикс '_terminal'. Это значит, что, используя данную функцию, дополнительно ничего писать не надо, т.к. она представляет из себя готовое решение типа задач. Всё взаимодействие происходит в терминале.
- 📲 любая функция, решающая задачу имеет суффикс '_solution'. Такая функция принимает аргументы на вход, которые ей следует предоставить. В описании каждой функции есть описание возвращаемого объекта.
- 📨 любая функция, решающая задачу имеет суффикс '_request'. Этот тип функций озволяет взаимодействовать с ней извне, например, отсылая в качестве входного параметра ввод пользователя.
## 🧱 Классы
- Классы данной библиотеки можно использовать вне функций, предавстовляемых данной библиотекой, но т.к. классы заточены под неё, то ими возможно будет неудобно пользоваться.

# ✅ Установка
### Консоль: pip install --upgrade MKN_third_codes
## Страница библиотеки: [MKN_lib][libaPage]

# 🧀 Не хотите париться с библиотекой?
## Бот [Lengendary Solver Bot][AlekseiBot] предоставляет возможность использования всех возможностей библиотеки в удобном интерфейсе телеграма.
### Автор: [Алексей Шумков][LehaVK]

## ☎️ Контакты
### Я в ВК: [Долгун Иван][vkCom]
### Я в Discord: ИVAN#2599

[vkCom]: https://vk.com/ivandolgun
[libaPage]: https://pypi.org/project/MKN-third-codes/
[AlekseiBot]: https://t.me/mkn_solver_bot
[LehaVK]: https://vk.com/miranchuk5959

==> MKN_third_codes-0.4.4.tar.gz: MKN_third_codes-0.4.4/README.md <==
### Здарова! Библиотека немного помогает с тервером по МКН 3

## 📦 Версия: 0.4.3

- Функции buckets_n_balls => задачи про урны
- Функции things_complexity => задачи про путаницу вещей
- Функции geometric_meeting => задачи про встречи
- Функции find_math_prediction => нахождение Математического ожидания
- Функция combinations => число сочетаний

# 🔩 Использование
## 📥 Импортирование
### from MKN_third_codes import solutions
## 🕹 Функции
- 📱 любая функция, решающая задачу имеет суффикс '_terminal'. Это значит, что, используя данную функцию, дополнительно ничего писать не надо, т.к. она представляет из себя готовое решение типа задач. Всё взаимодействие происходит в терминале.
- 📲 любая функция, решающая задачу имеет суффикс '_solution'. Такая функция принимает аргументы на вход, которые ей следует предоставить. В описании каждой функции есть описание возвращаемого объекта.
- 📨 любая функция, решающая задачу имеет суффикс '_request'. Этот тип функций позволяет взаимодействовать с ней извне, например, отсылая в качестве входного параметра ввод пользователя.
## 🧱 Классы
- Классы данной библиотеки можно использовать вне функций, предоставляемых данной библиотекой, но т.к. классы заточены под неё, то ими возможно будет неудобно пользоваться.

# ✅ Установка
### Консоль: pip install --upgrade MKN_third_codes
## Страница библиотеки: [MKN_lib][libaPage]

# 🧀 Не хотите париться с библиотекой?
## Бот [Lengendary Solver Bot][AlekseiBot] предоставляет возможность использования всех возможностей библиотеки в удобном интерфейсе телеграма.
### Автор: [Алексей Шумков][LehaVK]

## ☎️ Контакты
### Я в ВК: [Долгун Иван][vkCom]
### Я в Discord: ИVAN#2599

[vkCom]: https://vk.com/ivandolgun
[libaPage]: https://pypi.org/project/MKN-third-codes/
[AlekseiBot]: https://t.me/mkn_solver_bot
[LehaVK]: https://vk.com/miranchuk5959
